==> ci-hotel_V0.9.11_20101212.zip: ci-hotel_V0.0.11_20101212/system/application/views/res/confirm.php <==
<?php
include(dirname(__FILE__) . '/../header.php');
?>
<image src="<?php echo site_url('images/step4.png') ?>">

<h2>予約内容確認</h2>

<table class="inp">
<tr>
<th width="200px">プラン :</th>
<td><?php echo $plan_name ?></td>
</tr>
<th>チェックイン :</th>
<td>
<?php
$s_cin = $this->phpsession->get('cin');
echo $s_cin;
echo ' (' . $this->Common_model->week($s_cin) . ')';
?>
</td>
</tr>
<tr>
<th>チェックアウト :</th>
<td>
<?php
$s_cout = $this->phpsession->get('cout');
echo $s_cout;
echo ' (' . $this->Common_model->week($s_cout) . ')';
?>
</td>
</tr>
<tr><th>部屋タイプ :</th>
<td>
<?php echo $roomtype_name . '(' . $roomtypes_guest_min . '～' . $roomtypes_guest_max . '人)'; ?>
</td></tr>
<tr>
<th>部屋数 :</th>
<td><?php echo $this->phpsession->get('room_num') . '部屋'; ?></td>
</tr>
<tr>
<th>人数 :</th>
<td>
<?php
if ($this->phpsession->get('basic_num') > 0)
{
    echo "大人:"  . $this->phpsession->get('basic_num')  . "人&nbsp;";
}
if ($this->phpsession->get('child1_num') > 0)
{
    echo "子供A:" . $this->phpsession->get('child1_num') . "人&nbsp;";
}
if ($this->phpsession->get('child2_num') > 0)
{
    echo "子供B:" . $this->phpsession->get('child2_num') . "人&nbsp;";
}
if ($this->phpsession->get('child3_num') > 0)
{
    echo "子供C:" . $this->phpsession->get('child3_num') . "人&nbsp;";
}
if ($this->phpsession->get('child4_num') > 0)
{
    echo "子供D:" . $this->phpsession->get('child4_num') . "人";
}
?></td>
</tr>
<tr>
<th>料金 :</th>
<td>
<?php echo number_format($this->phpsession->get('total_price')) . "円"; ?>
</td>
</tr>
</table>

<table class="inp">
<tr>
<th width="200px">氏名(ひらがな) :</th>
<td>
<?php
echo $this->phpsession->get('name');
echo '(' . $this->phpsession->get('name_kana') . ')';
?>
</td>
</tr>
<tr>
<th>メールアドレス :</th>
<td>
<?php echo $this->phpsession->get('email') ?>
</td>
</tr>

<tr>
<th>住所 :</th>
<td>
<?php
echo '〒' . $this->phpsession->get('postcode') . "<br />\n";
echo $this->phpsession->get('prefecture') . "<br />\n";
echo $this->phpsession->get('city') . "<br />\n";
echo $this->phpsession->get('street') . "\n";
?>
</td>
</tr>

<tr>
<th>電話番号 :</th>
<td>
<?php echo $this->phpsession->get('phone') ?>
</td>
</tr>
</table>

<?php echo form_open('res/confirm/'); ?>
<input type="submit" name="submit" value="上記の内容で予約する" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V1.0.2_20101221.zip: ci-hotel_V1.0.2_20101221/system/application/views/res/confirm.php <==
<?php
include(dirname(__FILE__) . '/../header.php');
?>
<image src="<?php echo site_url('images/step4.png') ?>">

<h2>予約内容確認</h2>

<table class="inp">
<tr>
<th width="200px">プラン :</th>
<td><?php echo $plan_name ?></td>
</tr>
<th>チェックイン :</th>
<td>
<?php
$s_cin = $this->phpsession->get('cin');
echo $s_cin;
echo ' (' . $this->Common_model->week($s_cin) . ')';
?>
</td>
</tr>
<tr>
<th>チェックアウト :</th>
<td>
<?php
$s_cout = $this->phpsession->get('cout');
echo $s_cout;
echo ' (' . $this->Common_model->week($s_cout) . ')';
?>
</td>
</tr>
<tr><th>部屋タイプ :</th>
<td>
<?php echo $roomtype_name . '(' . $roomtypes_guest_min . '～' . $roomtypes_guest_max . '人)'; ?>
</td></tr>
<tr>
<th>部屋数 :</th>
<td><?php echo $this->phpsession->get('room_num') . '部屋'; ?></td>
</tr>
<tr>
<th>人数 :</th>
<td>
<?php
if ($this->phpsession->get('basic_num') > 0)
{
    echo "大人:"  . $this->phpsession->get('basic_num')  . "人&nbsp;";
}
if ($this->phpsession->get('child1_num') > 0)
{
    echo "子供A:" . $this->phpsession->get('child1_num') . "人&nbsp;";
}
if ($this->phpsession->get('child2_num') > 0)
{
    echo "子供B:" . $this->phpsession->get('child2_num') . "人&nbsp;";
}
if ($this->phpsession->get('child3_num') > 0)
{
    echo "子供C:" . $this->phpsession->get('child3_num') . "人&nbsp;";
}
if ($this->phpsession->get('child4_num') > 0)
{
    echo "子供D:" . $this->phpsession->get('child4_num') . "人";
}
?></td>
</tr>
<tr>
<th>料金 :</th>
<td>
<?php echo number_format($this->phpsession->get('total_price')) . "円"; ?>
</td>
</tr>
</table>

<table class="inp">
<tr>
<th width="200px">氏名(ひらがな) :</th>
<td>
<?php
echo $this->phpsession->get('name');
echo '(' . $this->phpsession->get('name_kana') . ')';
?>
</td>
</tr>
<tr>
<th>メールアドレス :</th>
<td>
<?php echo $this->phpsession->get('email') ?>
</td>
</tr>

<tr>
<th>住所 :</th>
<td>
<?php
echo '〒' . $this->phpsession->get('postcode') . "<br />\n";
echo $this->phpsession->get('prefecture') . "<br />\n";
echo $this->phpsession->get('city') . "<br />\n";
echo $this->phpsession->get('street') . "\n";
?>
</td>
</tr>

<tr>
<th>電話番号 :</th>
<td>
<?php echo $this->phpsession->get('phone') ?>
</td>
</tr>

<tr>
<th>チェックイン時刻 :</th>
<td>
<?php echo $this->phpsession->get('cinhour') ?>
</td>
</tr>

<tr>
<th>備考 :</th>
<td>
<?php echo $this->phpsession->get('memo') ?>
</td>
</tr>

</table>

<?php echo form_open('res/confirm/'); ?>
<input type="submit" name="submit" value="上記の内容で予約する" />
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
